<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>על אודות</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;מנהל הארכיונים שלLXQt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>מנהל ארכיונים פשוט ובלתי תלוי בסביבת שולחן עבודה שנכתב ב־Qt</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>יוצרים</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>פיתוח:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;‎

מנהל הארכיונים של LXQt נגזר מהיישומים הבאים:
* Engrampa משולחן העבודה MATE
* File Roller משולחן העבודה Gnome
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>רישיון</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>מנהל הארכיונים של LXQt

כל הזכויות שמורות (C) 2020 לצוות LXQt

תוכנית זו היא תוכנה חופשית, ניתן להפיץ ו/או לשנות
תחת תנאי הרישיון הציבורי הכללי של GNU כפי שמופץ על ידי
קרן התוכנה החופשית; בין אם גרסה 2 או כל גרסה עדכנית יותר
של הרישיון (לשיקולך).

תוכנית זו מופצת בתקווה שתביא תועלת, אך ללא כל אחריות, אפילו לא
מרומזת לשימוש מסחרי או התאמה לצרכים מסוימים.  נא לעיין
ברישיון הציבורי הכללי של GNU לפרטים נוספים.

לתוכנית זו אמור להיות מצורף עותק של הרישיון הציבורי הכללי של GNU,
אם לא, מוטב לשלוח מכתב אל Free Software Foundation, Inc.,‎
51‎ Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.‎</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>סוג הארכיון אינו נתמך.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*קובצי %1 ‏(*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>כל הסוגים הנתמכים</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>הפעלת הפקודה נכשלה.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>הפקודה לא נמצאה.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>הפקודה הסתיימה באופן חריג.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>נדרשת ססמה.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>כרך חסר.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>ערכת תווים שגויה.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>סוג הקובץ לא נתמך.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>אירעו שגיאות בלתי ידועות.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>פיצול לכרכים בגודל</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>ססמה:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>הצפנת רשימת הקבצים בנוסף</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="12"/>
        <source>Create Archive</source>
        <translation>יצירת ארכיון</translation>
    </message>
    <message>
        <location filename="../createfiledialog.cpp" line="14"/>
        <source>All files (*)</source>
        <translation>כל הקבצים (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>חילוץ</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>חילוץ &amp;כל הקבצים</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>חילוץ הקבצים ה&amp;נבחרים</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>פעולות</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>יצירת תיקיות מחדש</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="72"/>
        <source>Overwrite existing files</source>
        <translation>שכתוב קבצים קיימים</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="79"/>
        <source>Do not extract older files</source>
        <translation>לא לחלץ קבצים ישנים יותר</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="11"/>
        <source>Extract</source>
        <translation>חילוץ</translation>
    </message>
    <message>
        <location filename="../extractfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>כל הקבצים (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>File Archiver</source>
        <translation>מנהל ארכיונים</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>סינון קבצים…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>&amp;File</source>
        <translation>&amp;קובץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>ע&amp;ריכה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&amp;View</source>
        <translation>ת&amp;צוגה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>&amp;Icon Size</source>
        <translation>גודל &amp;סמל</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&amp;Help</source>
        <translation>ע&amp;זרה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Main Toolbar</source>
        <translation>סרגל הכלים הראשי</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <source>&amp;About</source>
        <translation>על &amp;אודות</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>&amp;Open</source>
        <translation>&amp;פתיחה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="213"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Save &amp;As</source>
        <translation>שמירה &amp;בשם</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>&amp;Extract</source>
        <translation>&amp;חילוץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>&amp;Test</source>
        <translation>ב&amp;דיקה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="249"/>
        <source>&amp;Properties</source>
        <translation>מ&amp;אפיינים</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="252"/>
        <source>Alt+Return</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>&amp;Close</source>
        <translation>&amp;סגירה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>Cu&amp;t</source>
        <translation>ג&amp;זירה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>&amp;Copy</source>
        <translation>ה&amp;עתקה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="294"/>
        <source>&amp;Paste</source>
        <translation>ה&amp;דבקה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>&amp;Rename</source>
        <translation>&amp;שינוי שם</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="317"/>
        <source>&amp;Delete</source>
        <translation>מ&amp;חיקה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>&amp;Select All</source>
        <translation>לבחור ה&amp;כול</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>&amp;Find</source>
        <translation>&amp;חיפוש</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <location filename="../mainwindow.ui" line="462"/>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>&amp;Add Files</source>
        <translation>הוספת &amp;קבצים</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>Add F&amp;older</source>
        <translation>הוס&amp;פת תיקייה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>Pass&amp;word</source>
        <translation>&amp;ססמה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="373"/>
        <source>&amp;Toolbar</source>
        <translation>ס&amp;רגל כלים</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="384"/>
        <source>&amp;Statusbar</source>
        <translation>סרגל מ&amp;צב</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>&amp;Directory Tree</source>
        <translation>&amp;עץ תיקיות</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="406"/>
        <source>S&amp;how as Folder</source>
        <translation>הצ&amp;גה כתיקייה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="409"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>Show &amp;All Files</source>
        <translation>הצגת כ&amp;ל הקבצים</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>St&amp;op</source>
        <translation>&amp;עצירה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Esc</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>&amp;Reload</source>
        <translation>&amp;רענון</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>Filename &amp;Encoding</source>
        <translation>&amp;קידוד שמות קבצים</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="454"/>
        <source>&amp;View Selected Items</source>
        <translation>ה&amp;צגת הפריטים הנבחרים</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>&amp;Filter</source>
        <translation>מ&amp;סנן</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>&amp;Expand</source>
        <translation>&amp;הרחבה</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>&amp;Collapse</source>
        <translation>&amp;צמצום</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>16 px</source>
        <translation>16 נק׳</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>24 px</source>
        <translation>24 נק׳</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>32 px</source>
        <translation>32 נק׳</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>48 px</source>
        <translation>48 נק׳</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <location filename="../mainwindow.cpp" line="397"/>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>All files (*)</source>
        <translation>כל הקבצים (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Add only if &amp;newer</source>
        <translation>להוסיף רק אם &amp;חדש יותר</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Confirm</source>
        <translation>אישור</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>למחוק את הקבצים הנבחרים?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="754"/>
        <source>Version: %1</source>
        <translation>גרסה: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>%p %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Success</source>
        <translation>הצלחה</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>No errors have been found.</source>
        <translation>לא נמצאו שגיאות.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="923"/>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>Open</source>
        <translation>פתיחה</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Add Files</source>
        <translation>הוספת קבצים</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Add Folder</source>
        <translation>הוספת תיקייה</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1008"/>
        <source>N/A</source>
        <translation>לא זמין</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1012"/>
        <source>Uncompressed Size:</source>
        <translation>גודל לאחר חילוץ:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1014"/>
        <source>Compression Ratio:</source>
        <translation>יחס דחיסה:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1033"/>
        <source>Link to</source>
        <translation>קישור אל</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1072"/>
        <source>File name</source>
        <translation>שם קובץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1073"/>
        <source>File Type</source>
        <translation>סוג קובץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1074"/>
        <source>File Size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1075"/>
        <source>Modified</source>
        <translation>מועד שינוי</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1076"/>
        <source>Encrypted</source>
        <translation>הצפנה</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1102"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>קובץ אחד</numerusform>
            <numerusform>שני קבצים</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>ססמה</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>הצפנת רשימת הקבצים</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>הצגת ססמה</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>ססמה:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;לתשומת לבך:&lt;/b&gt; הססמה תשמש להצפנת הקבצים שמתווספים לארכיון הנוכחי, בנוסף, כדי לפענח קבצים שחילצת מהארכיון הנוכחי. עם סגירת הארכיון הססמה תימחק.&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>התקדמות</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="300"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation>7‎-Zip‏ (‎.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>Tar מכווץ עם 7z‏ (‎.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>Tar מכווץ עם bzip2‏ (‎.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>Tar מכווץ עם bzip ‏(‎.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>ספר קומיקס בכיווץ Rar ‏(‎.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>ספר קומיקס בכיווץ Zip‏ (‎.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>Tar מכווץ עם gzip‏ (‎.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>Zip בפריסה עצמית (‎.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>Tar מכווץ עם lrzip ‏(‎.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>Tar מכווץ עם lzip ‏(‎.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>Tar מכווץ עם lzma ‏(‎.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>Tar מכווץ עם lzop‏ (‎.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation>תצורת דימות של Windows‏ (‎.wim)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Tar ללא כיווץ (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>Tar מכווץ עם compress‏ (‎.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>Tar מכווץ עם xz‏ (‎.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>Tar מכוון עם zstd‏ (‎.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>מתווסף קובץ: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="282"/>
        <source>Extracting file: </source>
        <translation>קובץ מחולץ: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>קובץ עובר הסרה: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>נמחקים קבצים מהארכיון</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>הארכיון נדחס מחדש</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>הארכיון נפרס</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>קובץ לא נמצא.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>סוג הארכיון אינו נתמך.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>הארכיון לא נמצא</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>אין לך את ההרשאות המתאימות.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>לא ניתן לשנות את סוג הארכיון הזה</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>אין אפשרות להוסיף ארכיון לתוך עצמו.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>לא ניתן למצוא את הכרך: %s</translation>
    </message>
</context>
</TS>
